@@ -547,9 +547,11 @@ def clean_path(path):
         relative_levels = len([directory for directory in path.split(os.sep) if directory == '..'])
         cwd = [directory for directory in os.getcwd().split(os.sep)] if ':' not in path else []
         path = '\\\\?\\' + os.sep.join(cwd[:len(cwd)-relative_levels] + [directory for directory in path.split(os.sep) if directory != ''][relative_levels:])
+        path = path.replace("\\\\?\\?\\","\\\\?\\")
     return path
-
-
+# \\?\?\Z:\Structure\Ra9\2021\21-0132 - EquariUI\EquariUI\EquariUI Beta\equari-beta\node_modules\equari-cryptadia-core\node_modules\preact-router\match\node_modules\.cache\.rts2_cache_cjs\rpt2_73e3afccd1fb4711c5e0a2849dd91b2323492db2\types\cache\0e26fd72fe37b4bfe0d3c7edcd1abb1561780380
+# test_path = r"Z:\Structure\Ra9\2021\21-0132 - EquariUI\EquariUI\EquariUI Beta\equari-beta\node_modules\equari-cryptadia-core\node_modules\preact-router\match\node_modules\.cache\.rts2_cache_cjs\rpt2_73e3afccd1fb4711c5e0a2849dd91b2323492db2\types\cache\0e26fd72fe37b4bfe0d3c7edcd1abb1561780380"
+# print(clean_path(test_path))
 
 def title_case(value,reverse=False):
     orig_type = 'list'
